//************************************************************
//
/** @file OnlineLoggerInfoWrapper.cc
 *
 * @brief C++ wrapper arnound brain dead OnlineLoggerInfo.
 */
//************************************************************

// sys
#include <iostream>

// client
#include "OnlineLoggerInfoWrapper.hh"

using namespace std;


//************************************************************
//
// OnlineLoggerInfoWrapper
//
//************************************************************

ostream & operator<<(ostream &os, const OnlineLoggerInfoWrapper &oli)
{
    os << "ip=\"" << oli.ip << '"'
       << ", name=\"" << oli.name << '"'
       << ", mbnr=\"" << oli.mbnr << '"'
       << ", deviceSN=\"" << oli.deviceSN << '"'
       << ", occupied=" << +oli.occupied
       << ", currentUser=\"" << oli.currentUser << '"'
       << ", loggerStatus=" << +oli.loggerStatus
       << ", wlan=" << +oli.wlan
       << ", tslEth0IP=\"" << oli.tslEth0IP << '"'
       << ", tslEth1IP=\"" << oli.tslEth1IP << '"'
       << ", tslId=" << +oli.tslId
       << ", tslNetworkId=" << oli.tslNetworkId
       << ", tslName=\"" << oli.tslName << '"'
       << ", deviceType=" << +oli.deviceType
       << ", fwVersion=\"" << oli.fwVersion << '"'
       << ", tmpBusPort=" << oli.tmpBusPort
       << ", udpPort=" << oli.udpPort
       << ", ftpPort=" << oli.ftpPort
       << ", isNotResponding=" << oli.isNotResponding
       << ", sfpIp=\"" << oli.sfpIp << '"'
       << ", sfpPort=" << oli.sfpPort;

    return os;
}

ostream & operator<<(ostream &os, const vector<OnlineLoggerInfoWrapper> &list)
{
    for (const auto l : list)
        os << l << endl;

    return os;
}


OnlineLoggerInfoWrapper::OnlineLoggerInfoWrapper(const char *_ip, const char *_name)
{
    ip = dupString(_ip);
    name = dupString(_name);
    mbnr = emptyString();
    deviceSN = emptyString();
    currentUser = emptyString();
    tslEth0IP = emptyString();
    tslEth1IP = emptyString();
    tslName = emptyString();
    fwVersion = emptyString();
    sfpIp = emptyString();
}


OnlineLoggerInfoWrapper &
OnlineLoggerInfoWrapper::operator= (OnlineLoggerInfoWrapper &&info)
{
    std::swap(ip, info.ip);
    std::swap(name, info.name);
    std::swap(mbnr, info.mbnr);
    std::swap(deviceSN, info.deviceSN);
    occupied = info.occupied;
    std::swap(currentUser, info.currentUser);
    loggerStatus = info.loggerStatus;
    wlan = info.wlan;
    std::swap(tslEth0IP, info.tslEth0IP);
    std::swap(tslEth1IP, info.tslEth1IP);
    tslId = info.tslId;
    tslNetworkId = info.tslNetworkId;
    std::swap(tslName, info.tslName);
    deviceType = info.deviceType;
    std::swap(fwVersion, info.fwVersion);
    tmpBusPort = info.tmpBusPort;
    udpPort = info.udpPort;
    ftpPort = info.ftpPort;
    isNotResponding = info.isNotResponding;
    std::swap(sfpIp, info.sfpIp);
    sfpPort = info.sfpPort;

    return *this;
}


char *
OnlineLoggerInfoWrapper::emptyString()
{
    char *s = new char[1];
    s[0] = '\0';
    return s;
}


char *
OnlineLoggerInfoWrapper::dupString(const char *sorig)
{
    const size_t n = strlen(sorig) + 1;
    char *sdup = new char[n];
    strncpy(sdup, sorig, n);
    return sdup;
}


void
OnlineLoggerInfoWrapper::emptyAll(OnlineLoggerInfoWrapper &dst)
{
    dst.ip = emptyString();
    dst.name = emptyString();
    dst.mbnr = emptyString();
    dst.deviceSN = emptyString();
    dst.currentUser = emptyString();
    dst.tslEth0IP = emptyString();
    dst.tslEth1IP = emptyString();
    dst.tslName = emptyString();
    dst.fwVersion = emptyString();
    dst.sfpIp = emptyString();
}


void
OnlineLoggerInfoWrapper::duplicateAll(OnlineLoggerInfoWrapper &dst, const OnlineLoggerInfo &info)
{
    dst.ip = dupString(info.ip);
    dst.name = dupString(info.name);
    dst.mbnr = dupString(info.mbnr);
    dst.deviceSN = dupString(info.deviceSN);
    dst.currentUser = dupString(info.currentUser);
    dst.tslEth0IP = dupString(info.tslEth0IP);
    dst.tslEth1IP = dupString(info.tslEth1IP);
    dst.tslName = dupString(info.tslName);
    dst.fwVersion = dupString(info.fwVersion);
    dst.sfpIp = dupString(info.sfpIp);
}


void
OnlineLoggerInfoWrapper::deleteAll()
{
    delete [] ip;
    delete [] name;
    delete [] mbnr;
    delete [] deviceSN;
    delete [] currentUser;
    delete [] tslEth0IP;
    delete [] tslEth1IP;
    delete [] tslName;
    delete [] fwVersion;
    delete [] sfpIp;
}


void
OnlineLoggerInfoWrapper::setIP(const char *_ip)
{
    delete [] ip;
    ip = dupString(_ip);
}


void
OnlineLoggerInfoWrapper::setName(const char *_name)
{
    delete [] name;
    name = dupString(_name);
}


void
OnlineLoggerInfoWrapper::setMbnr(const char *_mbnr)
{
    delete [] mbnr;
    name = dupString(_mbnr);
}
